@@ -1,12 +1,11 @@
 """ Core exporters apps config
 """
+
 import sys
 
 from django.apps import AppConfig
 
 
-# TODO: loaded two times (not a problem and may not happen in production)
-# see http://stackoverflow.com/a/16111968
 class CoreExportersAppConfig(AppConfig):
     """Exporters configuration"""
 
@@ -20,5 +19,4 @@ class CoreExportersAppConfig(AppConfig):
             from core_exporters_app.exporters import discover
 
             discover.init_periodic_tasks()
-            discover.discover_exporter()
             exporter_watch.init()
