@@ -1,5 +1,6 @@
 """ Exporter api
 """
+
 from core_exporters_app.components.exporter.models import Exporter
 
 
@@ -93,3 +94,12 @@ def upsert(exporter):
     """
     exporter.save_object()
     return exporter
+
+
+def get_none():
+    """Returns None queryset
+
+    Returns:
+
+    """
+    return Exporter.get_none()
