@@ -1,5 +1,6 @@
 """ Exporter model
 """
+
 from django.core.exceptions import ObjectDoesNotExist
 from django.core.validators import RegexValidator
 from django.db import models, IntegrityError
@@ -83,6 +84,8 @@ class Exporter(models.Model):
         Returns:
 
         """
+        if not template_id_list:
+            return Exporter.objects.none()
         queryset = Exporter.objects.all()
         for pk in template_id_list:
             queryset = queryset.filter(templates=pk)
@@ -182,6 +185,15 @@ class Exporter(models.Model):
         except Exception as ex:
             raise exceptions.ModelError(str(ex))
 
+    @staticmethod
+    def get_none():
+        """Return None object.
+
+        Returns:
+
+        """
+        return Exporter.objects.none()
+
     def clean(self):
         """Clean is called before saving
 
