@@ -1,5 +1,6 @@
 """ XSLT forms
 """
+
 from django import forms
 
 import core_main_app.components.xsl_transformation.api as xsl_api
@@ -9,7 +10,11 @@ class XsltSelectionForm(forms.Form):
     """Xslt selection form"""
 
     xslt_list = forms.MultipleChoiceField(
-        label="", widget=forms.SelectMultiple(), required=False
+        label="",
+        widget=forms.CheckboxSelectMultiple(
+            attrs={"class": "multiple-columns"}
+        ),
+        required=False,
     )
 
     def __init__(self, *args, **kwargs):
