@@ -29,15 +29,13 @@ load_associated_templates_form = function(exporterId){
         success: function(data){
             $("#banner_errors").hide();
             $("#form-associated-template-content").html(data.template);
-            InitSelectMultipleTemplates();
         },
         error:function(data){
-            if (data.responseText != ""){
-                $("#form_associated_templates_errors").html(data.responseText);
-                $("#banner_errors").show(500);
-                return (false);
-            }
-            return (true);
+            if (data.responseText === "")
+                return
+
+            $("#form_associated_templates_errors").html(data.responseText);
+            $("#banner_errors").show(500);
         }
     });
 };
@@ -68,17 +66,3 @@ submit_associated_templates_form = function(){
         }
     });
 };
-
-/**
- * Init the drop down list of templates
- */
-InitSelectMultipleTemplates = function()
-{
-    $('#id_templates_manager').fSelect({
-        placeholder: 'Select templates',
-        numDisplayed: 3,
-        overflowText: '{n} selected',
-        searchText: 'Search',
-        showSearch: true
-    });
-};
\ No newline at end of file
