@@ -1,10 +1,11 @@
 """ Forms admin exporter
 """
+
 from django import forms
 from django.forms import ModelForm
 
-from core_main_app.components.template import api as template_api
 from core_exporters_app.components.exporter.models import Exporter
+from core_main_app.components.template import api as template_api
 
 
 class EditExporterForm(ModelForm):
@@ -29,7 +30,9 @@ class AssociatedTemplatesForm(forms.Form):
 
     id = forms.CharField(widget=forms.HiddenInput(), required=False)
     templates_manager = forms.MultipleChoiceField(
-        label="", widget=forms.SelectMultiple(), required=False
+        label="",
+        widget=forms.CheckboxSelectMultiple(attrs={"class": "double-columns"}),
+        required=False,
     )
 
     def __init__(self, *args, **kwargs):
