@@ -1,5 +1,6 @@
 """ Ajax Exporter user
 """
+
 import json
 import logging
 
@@ -79,8 +80,11 @@ def open_form(request):
             json.dumps({"template": templates_selector.render(context)}),
             content_type="application/javascript",
         )
-    except Exception:
-        raise Exception("Error occurred during the form display")
+    except Exception as exception:
+        return HttpResponseBadRequest(
+            escape(str(exception)),
+            content_type="application/javascript",
+        )
 
 
 def check_download_status(request):
