@@ -1,5 +1,6 @@
 """ Exporter User views
 """
+
 import logging
 
 from django.http.response import HttpResponse
@@ -41,9 +42,9 @@ def download_exported_compressed_file(request):
         logger.error(
             "Something went wrong while downloading: %s", str(exception)
         )
-        context[
-            "message"
-        ] = "Something went wrong while downloading. Please contact administrator"
+        context["message"] = (
+            "Something went wrong while downloading. Please contact administrator."
+        )
 
     if exported_file and exported_file.is_ready:
         # the file is ready to be downloaded
